Core
----

Core checks are always available and do not have additional requirements.

:ref:`check`
    .. automodule:: geomancy.checks.base
        :noindex:

:ref:`checkEnv`
    .. automodule:: geomancy.checks.env
        :noindex:

:ref:`checkExec`
    .. automodule:: geomancy.checks.exec
        :noindex:

:ref:`checkPath`
    .. automodule:: geomancy.checks.path
        :noindex:

:ref:`checkPlatform`
    .. automodule:: geomancy.checks.platform
        :noindex:

:ref:`checkPythonPkg`
    .. automodule:: geomancy.checks.python
        :noindex:

.. versionchanged:: 0.9.3
    Environment variables are now referenced by the name preceded by a ``$`` and
    optional braces. e.g. ``$USER`` or ``${USER}``

.. toctree::
    :maxdepth: 1
    :glob:
    :hidden:

    *
